@@ -6,7 +6,7 @@ from .overlay import overlay
 from .topng import topng
 from .addbg import addbg
 from .instagram import instagram
-from .blur import blur
+#from .blur import blur
 
 
 CONTEXT_SETTINGS = dict(
@@ -21,7 +21,7 @@ def main():
     pass
 
 
-main.add_command(blur)
+#main.add_command(blur)
 main.add_command(instagram)
 main.add_command(split)
 main.add_command(overlay)
